@@ -1,13 +1,11 @@
 /**
  * \file sha1.h
  *
- *  Copyright (C) 2006-2010, Brainspark B.V.
- *
- *  This file is part of PolarSSL (http://www.polarssl.org)
- *  Lead Maintainer: Paul Bakker <polarssl_maintainer at polarssl.org>
- *
+ *  Copyright (C) 2006-2009, Paul Bakker <polarssl_maintainer at polarssl.org>
  *  All rights reserved.
  *
+ *  Joined copyright on original XySSL code with: Christophe Devine
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -23,12 +21,15 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+/* $Cambridge: exim/exim-src/src/pdkim/sha1.h,v 1.3 2009/12/07 13:05:07 tom Exp $ */
+
 #ifndef POLARSSL_SHA1_H
 #define POLARSSL_SHA1_H
 
 /**
  * \brief          SHA-1 context structure
  */
+
 #ifndef HAVE_SHA1_CONTEXT
 #define HAVE_SHA1_CONTEXT
 typedef struct sha1_context sha1_context;
@@ -44,6 +45,7 @@ struct sha1_context
     unsigned char opad[64];     /*!< HMAC: outer padding        */
 };
 
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -62,7 +64,7 @@ void sha1_starts( sha1_context *ctx );
  * \param input    buffer holding the  data
  * \param ilen     length of the input data
  */
-void sha1_update( sha1_context *ctx, const unsigned char *input, int ilen );
+void sha1_update( sha1_context *ctx, unsigned char *input, int ilen );
 
 /**
  * \brief          SHA-1 final digest
@@ -79,7 +81,7 @@ void sha1_finish( sha1_context *ctx, unsigned char output[20] );
  * \param ilen     length of the input data
  * \param output   SHA-1 checksum result
  */
-void sha1( const unsigned char *input, int ilen, unsigned char output[20] );
+void sha1( unsigned char *input, int ilen, unsigned char output[20] );
 
 /**
  * \brief          Output = SHA-1( file contents )
@@ -90,7 +92,7 @@ void sha1( const unsigned char *input, int ilen, unsigned char output[20] );
  * \return         0 if successful, 1 if fopen failed,
  *                 or 2 if fread failed
  */
-int sha1_file( const char *path, unsigned char output[20] );
+int sha1_file( char *path, unsigned char output[20] );
 
 /**
  * \brief          SHA-1 HMAC context setup
@@ -99,7 +101,7 @@ int sha1_file( const char *path, unsigned char output[20] );
  * \param key      HMAC secret key
  * \param keylen   length of the HMAC key
  */
-void sha1_hmac_starts( sha1_context *ctx, const unsigned char *key, int keylen );
+void sha1_hmac_starts( sha1_context *ctx, unsigned char *key, int keylen );
 
 /**
  * \brief          SHA-1 HMAC process buffer
@@ -108,7 +110,7 @@ void sha1_hmac_starts( sha1_context *ctx, const unsigned char *key, int keylen )
  * \param input    buffer holding the  data
  * \param ilen     length of the input data
  */
-void sha1_hmac_update( sha1_context *ctx, const unsigned char *input, int ilen );
+void sha1_hmac_update( sha1_context *ctx, unsigned char *input, int ilen );
 
 /**
  * \brief          SHA-1 HMAC final digest
@@ -118,13 +120,6 @@ void sha1_hmac_update( sha1_context *ctx, const unsigned char *input, int ilen )
  */
 void sha1_hmac_finish( sha1_context *ctx, unsigned char output[20] );
 
-/**
- * \brief          SHA-1 HMAC context reset
- *
- * \param ctx      HMAC context to be reset
- */
-void sha1_hmac_reset( sha1_context *ctx );
-
 /**
  * \brief          Output = HMAC-SHA-1( hmac key, input buffer )
  *
@@ -134,8 +129,8 @@ void sha1_hmac_reset( sha1_context *ctx );
  * \param ilen     length of the input data
  * \param output   HMAC-SHA-1 result
  */
-void sha1_hmac( const unsigned char *key, int keylen,
-                const unsigned char *input, int ilen,
+void sha1_hmac( unsigned char *key, int keylen,
+                unsigned char *input, int ilen,
                 unsigned char output[20] );
 
 #ifdef __cplusplus
