@@ -1,8 +1,10 @@
+/* $Cambridge: exim/exim-src/src/routers/queryprogram.h,v 1.6 2009/11/16 19:50:38 nm4 Exp $ */
+
 /*************************************************
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2003 */
+/* Copyright (c) University of Cambridge 1995 - 2009 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 
@@ -32,7 +34,7 @@ extern queryprogram_router_options_block queryprogram_router_option_defaults;
 /* The main and initialization entry points for the router */
 
 extern int queryprogram_router_entry(router_instance *, address_item *,
-  struct passwd *, BOOL, address_item **, address_item **,
+  struct passwd *, int, address_item **, address_item **,
   address_item **, address_item **);
 
 extern void queryprogram_router_init(router_instance *);
