@@ -1,8 +1,10 @@
+/* $Cambridge: exim/exim-src/src/store.h,v 1.5 2009/11/16 19:50:37 nm4 Exp $ */
+
 /*************************************************
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2003 */
+/* Copyright (c) University of Cambridge 1995 - 2009 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* Header for Exim's memory allocation functions */
@@ -10,15 +12,15 @@
 #ifndef STORE_H
 #define STORE_H
 
-/* Define symbols for identifying the two store pools. */
+/* Define symbols for identifying the store pools. */
 
-#define POOL_MAIN 0
-#define POOL_PERM 1
+enum { POOL_MAIN, POOL_PERM, POOL_SEARCH };
 
-/* This variable is set by store_get() to its yield, and by store_reset() to
-NULL. This allows string_cat() to optimize its store handling. */
+/* This variable (the one for the current pool) is set by store_get() to its
+yield, and by store_reset() to NULL. This allows string_cat() to optimize its
+store handling. */
 
-extern void *store_last_get;
+extern void *store_last_get[3];
 
 /* This variable contains the current store pool number. */
 
